@@ -1,8 +1,8 @@
 <?php
 /*
  * Phamm - http://www.phamm.org - <team AT phamm DOT org>
- * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
- * Project sponsored by RHX Studio Snc - www.rhx.it
+ * Copyright (C) 2004-2016 Alessandro De Zorzi and Mirko Grava
+ * Project sponsored by RHX Srl - www.rhx.it
  *  
  * Phamm is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,9 @@ define ('SUFFIX','dc=example,dc=tld');
 // The admin bind dn (could be rootdn)
 define ('BINDDN','cn=admin,dc=example,dc=tld');
 
+// Another additional bind dn (optional)
+define ('BINDDN_EXTRA','cn=adminplus,dc=example,dc=tld');
+
 // The Phamm container
 define ('LDAP_BASE','o=hosting,dc=example,dc=tld');
 
@@ -64,7 +67,7 @@ define('ORG_TITLE','Phamm');
 define('ORG_URL','http://www.phamm.org');
 
 // Logo
-define('ORG_LOGO', './img/phamm_100.png');
+define('ORG_LOGO', './img/phamm_logo.svg');
 
 // CSS Style
 $style = 'phamm';
@@ -84,6 +87,7 @@ $supported_languages["pl_PL"] = "Polish";
 $supported_languages["ru_RU"] = "Russian";
 $supported_languages["vi_VN"] = "Tiếng Việt"; // Vietnamese
 $supported_languages["da_DK"] = "Dansk"; // Danish
+$supported_languages["pt_BR"] = "Portuguese";
 // $supported_languages["ll_CC"] = "Your language here";
 
 // This TLDs menu
@@ -129,8 +133,8 @@ $plugins_exclusion = array("mail","alias");
 // *===   System Settings    ===*
 // *============================*
 
-// Phamm Version (+ indicate a CVS version)
-define ('VERSION','0.5.18');
+// Phamm Version (+ indicate a SVN version)
+define ('VERSION','0.6.5');
 
 // Useful if you want hide the version [0,1]
 define ('HIDE_VERSION',0);
@@ -173,7 +177,17 @@ define ('LOG_FILE','/var/log/phamm.log');
 // Standard LDAP encryption type [CRYPT,MD5,CLEAR]
 define ('ENC_TYPE','CRYPT');
 
+// Standard Crypt salt [RANDOM, PASSWORD, SALT]
+//   RANDOM - Choose a random salt
+//   PASSWORD - Guess salt by password
+//   Anything else - Use this phrase as a salt
+define ('CRYPT_SALT', 'RANDOM');
+
+// Phamm autogenerate UID from e-mail
+// set char used instead @ (default=.)
+// i.e. info@example.com produce UID=info.example.com
+define ('CHR_UID_ACCOUNT','.');
+
 // Permit login without @domain (use it with carefull)
 // define ('DEFAULT_DOMAIN','example.tld');
 
-?>
