@@ -72,7 +72,7 @@ if (!$connect)
 {
     phamm_print_message ('error',_("Connection to LDAP Server Failed!"));
     
-    print PhammLdap::phamm_error();
+    phamm_print_message('error', PhammLdap::phamm_error());
 
     echo $page_exit;
 }
@@ -158,7 +158,7 @@ elseif($login->login_check())
 	$domain = $_SESSION["phamm"]["domain"];
     
     // Create domain object
-    if (isset($domain))
+    if (isset($domain) && !empty($domain))
     {
 	$domain_obj = new PhammLdap();
 	$domain_val = $domain_obj->phamm_self_values ('vd='.$domain.','.LDAP_BASE, $filter="(vd=$domain)");
@@ -196,7 +196,7 @@ elseif($login->login_check())
     if ($_SESSION["login"]["level"] > 2)
 	phamm_print_xhtml ( navigation($initial) );
 
-    // echo $action;
+    # echo $action;
 
     switch ($action) :
 
@@ -220,9 +220,9 @@ elseif($login->login_check())
 	$command = $_GET["command"];
 
     foreach ($values as $k => $v)
-	phamm_print_message('success',sprintf(_("%s modified"),$k));
+	phamm_print_message('success',sprintf(_("modifying %s"),$k));
 
-    $r = group_actions ($command,$values);
+    $r = group_actions ($command, $values);
     
     $log->phamm_log ($pn,$_SESSION["login"]["username"],$action,$r);
 
@@ -239,7 +239,7 @@ elseif($login->login_check())
     {
         phamm_print_message('error',_("Changes have not performed"));
         
-	print PhammLdap::phamm_error();
+	phamm_print_message('error', PhammLdap::phamm_error());
     }
 
     break;
@@ -288,6 +288,7 @@ case "insert_domain" :
     {
         $entry["objectclass"][0]	= "top";
         $entry["objectclass"][1]	= "VirtualDomain";
+        $entry["objectclass"][2]	= "inetLocalMailRecipient";
 
         $entry["vd"]				= $domain_new;
         $entry["lastChange"]		= time();
@@ -369,7 +370,7 @@ case "insert_domain" :
         else
 	{
             phamm_print_message('error',sprintf(_("An Unexpected Error Occurred during %s Addition!"),$domain_new));
-            print PhammLdap::phamm_error();
+	    phamm_print_message('error', PhammLdap::phamm_error());
 	}
 
     }
@@ -411,7 +412,7 @@ case "add_account" :
 	if (!$syntax)
 	    phamm_print_message('error',_("Special Characters not Allowed in E-mail address"));
 	if ($exceeds_max_account)
-	    phamm_print_message('error',_("The maximum number of accounts (".$max_accounts_allowed.") has been exceeded!"));
+	    phamm_print_message('warning',sprintf(_("The maximum number of accounts (%s) has been reached or exceeded!"), $max_accounts_allowed));
         phamm_print_xhtml ( form_add_account ($_POST["account_new"]) );
     }
 
@@ -440,7 +441,7 @@ case "modify_account" :
         phamm_print_message ('warning',_("please, insert a forward destination or disable Forward!"));
     //
     // ////////////////////////////////////////////////////////////
-
+    
     phamm_print_xhtml ( form_add_account_2 ($values[0]["mail"][0], 'update_account', $values) );
 
     break;
@@ -665,6 +666,7 @@ case "insert_account" :
     //
 case "update_account" :
 
+
     $values = $_POST["values"];
     $values_date = (isset($_POST["values_date"]) ? $_POST["values_date"] : null);
     $values_multi = (isset($_POST["values_multi"]) ? $_POST["values_multi"] : null);
