@@ -1,6 +1,6 @@
 #!/bin/bash
 # save all the base dn in a file .ldif
-ROOTDN="cn=manager,dc=example,dc=tld"
+ROOTDN="cn=admin,dc=example,dc=tld"
 ROOTPW="rhx"
 BASEDN="dc=example,dc=tld"
 LDAPSER="localhost"
