@@ -273,7 +273,7 @@ function accounts_list($domain,$values,$initial, $domain_val)
     global $pn;
     global $pv;
     global $action;
-    
+
     // Rapresentative ObjectClass
     $myObjectClass = (isset($pv[$pn]["ACCOUNT"]["OBJECTCLASSES"]) ? key($pv[$pn]["ACCOUNT"]["OBJECTCLASSES"]) : 'virtualMailAccount');
 
@@ -416,6 +416,10 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 {
     global $action;
     global $minAuthLevel;
+    global $domain;
+    
+    $dn_domain = 'vd='.$domain.','.LDAP_BASE;
+    $domain_values = PhammLdap::phamm_self_values ($dn_domain, $filter="(objectClass=*)");
 
     $tag = '';
 
@@ -433,12 +437,57 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 	$hidden = (isset($attr["HIDDEN"]) ? 'type="hidden"' : null);
 	$minAuthLevel = (isset($attr["MINAUTHLEVEL"]) ? $attr["MINAUTHLEVEL"] : 0);
         $size = (isset($attr["SIZE"]) && !isset($attr["HIDDEN"]) ? 'size="'.$attr["SIZE"].'"' : null);
+	$disabled = (isset($attr["DISABLED"]) ? 'disabled="disabled"' : null);
 
         $maxlength = (isset($attr["MAXLENGHT"]) ? strtolower($attr["MAXLENGTH"]) : null);
 
         $subordinated = (isset($attr["SUBORDINATED"]) ? strtoupper($attr["SUBORDINATED"]) : null);
         $subordinatedreverse = (isset($attr["SUBORDINATEDREVERSE"]) ? strtoupper($attr["SUBORDINATEDREVERSE"]) : null);
-        
+	
+	$max_key = strtolower('max'.$key);
+	if (isset ($domain_values[0][$max_key][0]))
+	{
+	  // Disable value is possible only from TRUE to FALSE
+	  if (isset($myvalues[0][$name][0]) || $myvalues[0][$name][0] == 'FALSE') :
+
+	  $max_val = $domain_values[0][$max_key][0];
+	  
+	    // For Bool attrbute only check the sum of total account with attribute set TRUE
+	    if ($attr["BOOL"] == 1)
+	    {
+		$active_val = PhammLdap::phamm_self_values ($dn_domain,'(&(objectClass=*)('.$key.'=TRUE))');
+		$current_val_count = $active_val["count"];
+	    }
+	    
+	    // For other attributes sum the values
+	    else
+	    {
+		$active_val = PhammLdap::phamm_search ('vd='.$domain.','.LDAP_BASE,'(&(objectClass=VirtualMailAccount))',array($key));
+	    
+		$total_key = 0;
+		foreach ($active_val as $one_val)
+		{
+		    if ($one_val[$key][0])
+		    {
+			$total_key = ($total_key + $one_val[$key][0]);
+		    }
+		}
+
+		// @todo
+		if ('quota' == $key)
+			$total_key = ($total_key/1024/1024 - $active_val['count'] * 2000);
+
+		$current_val_count = $total_key;
+	    }
+
+	  if ($current_val_count >= $max_val)
+	  {
+	    phamm_print_message('info',sprintf(_("The maximum number of attribute %s (%s) has been reached or exceeded. Attribute has been disabled!"), $key, $max_val));
+		    $disabled = 'disabled="disabled"';
+	  }
+	  endif;
+	}  
+    
 	// Set XHTML Tags
 	$required = (isset($attr["REQUIRED"]) ? ' *' : null);
 
@@ -557,8 +606,7 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 	{
 	    $reverse = (isset($attr["REVERSE"]) ? 1 : null);
 
-	    $tag .= trueorfalse("values[".$p_name."]",$value,$name,$reverse);
-
+	    $tag .= trueorfalse("values[".$p_name."]",$value,$name,$reverse, $disabled);
 	}
         
 	// Options (select)
@@ -639,7 +687,7 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 
 	    // Show Value Only if auth level > level required
 	    if ($_SESSION["login"]["level"] >= $minAuthLevel)
-	        $tag .= '<input type="'.$input_type.'" class="form-control" value="'.$value.'" name="values['.$p_name.']['.$name.']" '.$size.' />';
+	        $tag .= '<input type="'.$input_type.'" class="form-control" value="'.$value.'" name="values['.$p_name.']['.$name.']" '.$size.' '.$disabled.' />';
 	    elseif (!isset($hidden))
 	        $tag .= $value;
         }
@@ -678,6 +726,7 @@ function form_add_domain_2 ($domain_new, $action, $values, $values_postmaster)
     global $pv;
     global $domain;
     
+
     if (in_array($action,array('update_account','modify_account')))
 	$submit_label = _("Modify domain");
     else
@@ -696,10 +745,10 @@ function form_add_domain_2 ($domain_new, $action, $values, $values_postmaster)
     $tag .= '<table class="table table-bordered">'."\n";
 
     $tag .= '<tr class="warning"><td>'._("Password").'</td>'."\n";
-    $tag .= '<td><input type="password" class="form-control" name="password1" value="" size="15" maxlength="15" /></td></tr>'."\n";
+    $tag .= '<td><input autocomplete="off" type="password" class="form-control" name="password1" value="" size="50" maxlength="50" /></td></tr>'."\n";
 
     $tag .= '<tr class="warning"><td>'._("Confirm Password").'</td>'."\n";
-    $tag .= '<td><input type="password" class="form-control" name="password2" value="" size="15" maxlength="15" /></td></tr>'."\n";
+    $tag .= '<td><input autocomplete="off" type="password" class="form-control" name="password2" value="" size="50" maxlength="50" /></td></tr>'."\n";
     
     foreach ($pv as $name => $p_value)
     {
@@ -764,7 +813,7 @@ function form_add_account ()
 *
 **/
 
-function form_add_account_2 ($account_new,$action,$values)
+function form_add_account_2 ($account_new, $action, $values, $disabled=array())
 {
     global $plugins;
     global $pv;
@@ -774,7 +823,7 @@ function form_add_account_2 ($account_new,$action,$values)
     global $sn;
     #global $values;
     global $plugins_exclusion;
-
+  
     if (in_array($action,array('modify_account','update_account')))
 	$submit_label = _("Modify account");
     else
@@ -793,10 +842,10 @@ function form_add_account_2 ($account_new,$action,$values)
     $tag .= '<table class="table table-bordered">'."\n";
 
     $tag .= '<tr class="warning"><td>'._("Password").'</td>'."\n";
-    $tag .= '<td><input type="password" class="form-control" name="password1" value="" size="15" maxlength="15" /></td></tr>'."\n";
+    $tag .= '<td><input autocomplete="off" type="password" class="form-control" name="password1" value="" size="50" maxlength="50" /></td></tr>'."\n";
 
     $tag .= '<tr class="warning"><td>'._("Confirm Password").'</td>'."\n";
-    $tag .= '<td><input type="password" class="form-control" name="password2" value="" size="15" maxlength="15" /></td></tr>'."\n";
+    $tag .= '<td><input autocomplete="off" type="password" class="form-control" name="password2" value="" size="50" maxlength="50" /></td></tr>'."\n";
 
     $tag .= '<tr class="warning"><td>'._("Name").' *</td>'."\n";
     $tag .= '<td><input type="text" class="form-control" name="givenname" value="'.stripslashes($givenName).'" size="15" maxlength="50" /></td></tr>'."\n";
@@ -933,7 +982,7 @@ function navigation ($initial)
 * @return mixed
 **/
 
-function trueorfalse($table,$value,$field,$reverse)
+function trueorfalse($table, $value, $field, $reverse, $disabled)
 {
     global $minAuthLevel;
 
@@ -959,8 +1008,10 @@ function trueorfalse($table,$value,$field,$reverse)
     if ($_SESSION["login"]["level"] >= $minAuthLevel)
     {
 	$js_string = ($field == 'vacationactive' ? 'onchange="subordinatedelete.checked=true;"' : '');
+	#$disabled_string = ($disabled  ? 'disabled="disabled"' : '');
+	$disabled_string = ($disabled  ? 'readonly="readonly"' : '');
 
-	$tag .= '<select class="form-control" name="'.$table.'['.$field.']" '.$js_string.'>';
+	$tag .= '<select class="form-control" name="'.$table.'['.$field.']" '.$js_string.' '.$disabled_string.'>';
 
 	$selected = ($value == 'TRUE' || $value == 'true' ? 'selected="selected"' : '');
 
@@ -1420,4 +1471,12 @@ function refresh ($url, $force_meta = false, $seconds = 0)
     exit;
 }
 
-
+function debug($value)
+{
+  print '<pre>';
+  if (is_array($value))
+    print_r($value);
+  if (is_object($value))
+    var_dump($value);
+  print '</pre>';
+}
